@@ -1,5 +1,5 @@
 from brain_games.cli import welcome_user
-from brain_games.even_game import play_even_game
+from brain_games.games.even_game import play_even_game
 
 
 def main():
